@@ -1,4 +1,4 @@
-# Copyright (c) 2015 Intel Corporation
+# Copyright (c) 2014 Mirantis Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,7 +15,7 @@
 
 from sahara import exceptions as ex
 from sahara.plugins.cdh import confighints_helper as ch_helper
-from sahara.plugins.cdh.v5_4_0 import cloudera_utils as cu
+from sahara.plugins.cdh.v5_3_0 import cloudera_utils as cu
 from sahara.plugins import exceptions as pl_ex
 from sahara.plugins import utils as u
 from sahara.service.edp import hdfs_helper
@@ -23,7 +23,7 @@ from sahara.service.edp.oozie import engine as edp_engine
 from sahara.service.edp.spark import engine as edp_spark_engine
 from sahara.utils import edp
 
-CU = cu.ClouderaUtilsV540()
+CU = cu.ClouderaUtilsV530()
 
 
 class EdpOozieEngine(edp_engine.OozieJobEngine):
@@ -39,11 +39,8 @@ class EdpOozieEngine(edp_engine.OozieJobEngine):
         return 'http://%s:11000/oozie' % oozie_ip
 
     def get_name_node_uri(self, cluster):
-        if len(CU.pu.get_jns(cluster)) > 0:
-            return 'hdfs://%s' % CU.NAME_SERVICE
-        else:
-            namenode_ip = CU.pu.get_namenode(cluster).fqdn()
-            return 'hdfs://%s:8020' % namenode_ip
+        namenode_ip = CU.pu.get_namenode(cluster).fqdn()
+        return 'hdfs://%s:8020' % namenode_ip
 
     def get_resource_manager_uri(self, cluster):
         resourcemanager_ip = CU.pu.get_resourcemanager(cluster).fqdn()
@@ -64,21 +61,21 @@ class EdpOozieEngine(edp_engine.OozieJobEngine):
     def get_possible_job_config(job_type):
         if edp.compare_job_type(job_type, edp.JOB_TYPE_HIVE):
             return {'job_config': ch_helper.get_possible_hive_config_from(
-                    'plugins/cdh/v5_4_0/resources/hive-site.xml')}
+                    'plugins/cdh/v5_3_0/resources/hive-site.xml')}
         if edp.compare_job_type(job_type,
                                 edp.JOB_TYPE_MAPREDUCE,
                                 edp.JOB_TYPE_MAPREDUCE_STREAMING):
             return {'job_config': ch_helper.get_possible_mapreduce_config_from(
-                    'plugins/cdh/v5_4_0/resources/mapred-site.xml')}
+                    'plugins/cdh/v5_3_0/resources/mapred-site.xml')}
         if edp.compare_job_type(job_type, edp.JOB_TYPE_PIG):
             return {'job_config': ch_helper.get_possible_pig_config_from(
-                    'plugins/cdh/v5_4_0/resources/mapred-site.xml')}
+                    'plugins/cdh/v5_3_0/resources/mapred-site.xml')}
         return edp_engine.OozieJobEngine.get_possible_job_config(job_type)
 
 
 class EdpSparkEngine(edp_spark_engine.SparkJobEngine):
 
-    edp_base_version = "5.4.0"
+    edp_base_version = "5.3.0"
 
     def __init__(self, cluster):
         super(EdpSparkEngine, self).__init__(cluster)
