@@ -20,19 +20,17 @@ from sahara.plugins.mapr.services.hbase import hbase
 from sahara.plugins.mapr.services.hive import hive
 from sahara.plugins.mapr.services.httpfs import httpfs
 from sahara.plugins.mapr.services.hue import hue
-from sahara.plugins.mapr.services.impala import impala
 from sahara.plugins.mapr.services.mahout import mahout
-from sahara.plugins.mapr.services.management import management as mng
+from sahara.plugins.mapr.services.management import management
 from sahara.plugins.mapr.services.mapreduce import mapreduce
 from sahara.plugins.mapr.services.maprfs import maprfs
 from sahara.plugins.mapr.services.oozie import oozie
 from sahara.plugins.mapr.services.pig import pig
 from sahara.plugins.mapr.services.sqoop import sqoop2
 from sahara.plugins.mapr.services.swift import swift
-import sahara.plugins.mapr.versions.v5_0_0_mrv1.context as c
+import sahara.plugins.mapr.versions.v4_0_1_mrv1.context as c
 
-
-version = "5.0.0.mrv1"
+version = '4.0.1.mrv1'
 
 
 class VersionHandler(bvh.BaseVersionHandler):
@@ -42,28 +40,30 @@ class VersionHandler(bvh.BaseVersionHandler):
         self._required_services = [
             mapreduce.MapReduce(),
             maprfs.MapRFS(),
-            mng.Management(),
+            management.Management(),
             oozie.Oozie(),
         ]
         self._services = [
-            hive.HiveV013(),
-            hive.HiveV10(),
-            impala.ImpalaV141(),
-            pig.PigV014(),
-            flume.Flume(),
-            sqoop2.Sqoop2(),
-            mahout.MahoutV010(),
-            oozie.OozieV410(),
-            hue.HueV370(),
-            hue.HueV381(),
-            hbase.HBaseV0989(),
-            hbase.HBaseV09812(),
-            drill.DrillV11(),
-            mapreduce.MapReduce(),
             maprfs.MapRFS(),
-            mng.Management(),
+            management.Management(),
+            oozie.OozieV401(),
+            hive.HiveV013(),
+            hbase.HBaseV094(),
+            hbase.HBaseV0987(),
+            hbase.HBaseV0989(),
             httpfs.HttpFS(),
+            mahout.MahoutV09(),
+            pig.PigV013(),
+            pig.PigV014(),
             swift.Swift(),
+            mapreduce.MapReduce(),
+            flume.Flume(),
+            drill.DrillV07(),
+            drill.DrillV08(),
+            drill.DrillV09(),
+            sqoop2.Sqoop2(),
+            hue.HueV360(),
+            hue.HueV370(),
         ]
 
     def get_context(self, cluster, added=None, removed=None):
