@@ -13,25 +13,26 @@
 # under the License.
 
 
-from sahara.plugins.mapr.base import base_version_handler as bvh
+import sahara.plugins.mapr.base.base_version_handler as bvh
 from sahara.plugins.mapr.services.drill import drill
 from sahara.plugins.mapr.services.flume import flume
 from sahara.plugins.mapr.services.hbase import hbase
 from sahara.plugins.mapr.services.hive import hive
 from sahara.plugins.mapr.services.httpfs import httpfs
 from sahara.plugins.mapr.services.hue import hue
+from sahara.plugins.mapr.services.impala import impala
 from sahara.plugins.mapr.services.mahout import mahout
-from sahara.plugins.mapr.services.management import management
+from sahara.plugins.mapr.services.management import management as mng
 from sahara.plugins.mapr.services.maprfs import maprfs
 from sahara.plugins.mapr.services.oozie import oozie
 from sahara.plugins.mapr.services.pig import pig
 from sahara.plugins.mapr.services.sqoop import sqoop2
 from sahara.plugins.mapr.services.swift import swift
 from sahara.plugins.mapr.services.yarn import yarn
-import sahara.plugins.mapr.versions.v4_0_1_mrv2.context as c
+import sahara.plugins.mapr.versions.v5_0_0_mrv2.context as c
 
 
-version = '4.0.1.mrv2'
+version = "5.0.0.mrv2"
 
 
 class VersionHandler(bvh.BaseVersionHandler):
@@ -39,32 +40,30 @@ class VersionHandler(bvh.BaseVersionHandler):
         super(VersionHandler, self).__init__()
         self._version = version
         self._required_services = [
-            yarn.YARNv241(),
+            yarn.YARNv270(),
             maprfs.MapRFS(),
-            management.Management(),
+            mng.Management(),
             oozie.Oozie(),
         ]
         self._services = [
-            maprfs.MapRFS(),
-            management.Management(),
-            oozie.OozieV401(),
             hive.HiveV013(),
-            hbase.HBaseV094(),
-            hbase.HBaseV0987(),
-            hbase.HBaseV0989(),
-            httpfs.HttpFS(),
-            mahout.MahoutV09(),
-            pig.PigV013(),
+            hive.HiveV10(),
+            impala.ImpalaV141(),
             pig.PigV014(),
-            swift.Swift(),
-            yarn.YARNv241(),
             flume.Flume(),
-            drill.DrillV07(),
-            drill.DrillV08(),
-            drill.DrillV09(),
             sqoop2.Sqoop2(),
-            hue.HueV360(),
+            mahout.MahoutV010(),
+            oozie.OozieV410(),
             hue.HueV370(),
+            hue.HueV381(),
+            hbase.HBaseV0989(),
+            hbase.HBaseV09812(),
+            drill.DrillV11(),
+            yarn.YARNv270(),
+            maprfs.MapRFS(),
+            mng.Management(),
+            httpfs.HttpFS(),
+            swift.Swift(),
         ]
 
     def get_context(self, cluster, added=None, removed=None):
